@@ -1,8 +1,8 @@
-/*  $Id: BurgerSpaceClient.cpp,v 1.7 2017/12/09 04:29:00 sarrazip Exp $
+/*  $Id: BurgerSpaceClient.cpp,v 1.10 2021/06/13 02:43:46 sarrazip Exp $
     BurgerSpaceClient.cpp - Game client
 
     burgerspace - A hamburger-smashing video game.
-    Copyright (C) 2001-2013 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2001-2021 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -390,8 +390,10 @@ BurgerSpaceClient::runClientMode(Uint32 millisecondsPerFrame)
                     // go wait for reactivation, i.e., stop calling tick().
                     // This avoids using the CPU while the app is not active.
                     // waitForReactivation() is inherited from flatzebra::GameEngine.
+                    // processActiveEvent is inherited from the base class and is controlled
+                    // by option --no-active-event.
                     //
-                    if (event.active.gain == 0 && !waitForReactivation())
+                    if (processActiveEvent && event.active.gain == 0 && !waitForReactivation())
                         return;  // wait ended with quit or with wait error
                     break;
 
@@ -782,7 +784,7 @@ BurgerSpaceClient::showSlotDirectory()
     // Scan the saved games directory and build a table of available games:
     for (size_t slotNum = 1; slotNum <= 9; slotNum++)
     {
-        char slotDesc[32], fileTime[32];
+        char slotDesc[64], fileTime[32];
         string filename = dirname + "/" + formSavedGameFilename(slotNum);
         ifstream file(filename.c_str());
         if (!file)
