@@ -1,8 +1,8 @@
-/*  $Id: BurgerSpaceServer.cpp,v 1.11 2019/08/09 00:06:34 sarrazip Exp $
+/*  $Id: BurgerSpaceServer.cpp,v 1.15 2022/11/22 01:35:20 sarrazip Exp $
     BurgerSpaceServer.cpp - Main engine
 
     burgerspace - A hamburger-smashing video game.
-    Copyright (C) 2001-2013 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2001-2022 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -241,7 +241,6 @@ BurgerSpaceServer::tableIngredientsLevel1[] =
 
 const char *
 BurgerSpaceServer::levelDescriptor2[] =
-// Description of the second level's setting.
 {
     "eeeeeeeeeeeeeeeeeeeeeee",
     "eeeeeeeeeeeeeeeeeeeeeee",
@@ -296,7 +295,6 @@ BurgerSpaceServer::tableIngredientsLevel2[] =
 
 const char *
 BurgerSpaceServer::levelDescriptor3[] =
-// Description of the second level's setting.
 {
     "eeeeeeeeeeeeeeeeeeeeeee",
     "eeeeeeeeeeeeeeeeeeeeeee",
@@ -357,7 +355,6 @@ BurgerSpaceServer::tableIngredientsLevel3[] =
 
 const char *
 BurgerSpaceServer::levelDescriptor4[] =
-// Description of the second level's setting.
 {
     "eeeeeeeeeeeeeeeeeeeeeee",
     "eeeeeeeeeeeeeeeeeeeeeee",
@@ -428,7 +425,6 @@ BurgerSpaceServer::tableIngredientsLevel4[] =
 
 const char *
 BurgerSpaceServer::levelDescriptor5[] =
-// Description of the second level's setting.
 {
     "eeeeeeeeeeeeeeeeeeeeeee",
     "eeeeeeeeeeeeeeeeeeeeeee",
@@ -479,7 +475,6 @@ BurgerSpaceServer::tableIngredientsLevel5[] =
 
 const char *
 BurgerSpaceServer::levelDescriptor6[] =
-// Description of the second level's setting.
 {
     "eeeeeeeeeeeeeeeeeeeeeee",
     "eeeeeeeeeeeeeeeeeeeeeee",
@@ -733,7 +728,8 @@ BurgerSpaceServer::Level::getTextDescription() const
 
 
 BurgerSpaceServer::BurgerSpaceServer(int initLevelNumber,
-                                    bool _oldMotionMode)
+                                     bool _oldMotionMode,
+                                     bool _hideLandedEnemies)
   : theScreenSizeInPixels(SCREEN_WIDTH_IN_PIXELS, SCREEN_HEIGHT_IN_PIXELS),
 
     initLevelNo(1),
@@ -769,6 +765,7 @@ BurgerSpaceServer::BurgerSpaceServer(int initLevelNumber,
     bottomBunPA(4),
     ingredientSprites(),
     ingredientGroups(),
+    hideLandedEnemies(_hideLandedEnemies),
 
     treatPA(3),
     treatSprites(),
@@ -2983,7 +2980,7 @@ BurgerSpaceServer::drawComplexEnemySprites(const SpriteList &slist, int oscBit)
         EnemySprite *enemy = dynamic_cast<EnemySprite *>(*it);
         assert(enemy != NULL);
 
-        if (enemy->getDisappearanceTime() != 0)
+        if (hideLandedEnemies && enemy->getDisappearanceTime() != 0)
         {
             // Set an invalid index in the sprite so that
             // it does not get displayed.
@@ -2996,6 +2993,10 @@ BurgerSpaceServer::drawComplexEnemySprites(const SpriteList &slist, int oscBit)
             {
                 // don't touch enemy->currentPixmapIndex
             }
+            else if (!hideLandedEnemies && enemy->getDisappearanceTime() != 0)  // if landed enemy still frozen
+            {
+                spriteNo = 12;  // show the enemy as peppered, but frozen
+            }
             else if (enemy->getTimeToDie() != 0)   // if dying
             {
                 int ttd = enemy->getTimeToDie();
