@@ -1,8 +1,8 @@
-/*  $Id: BurgerSpaceServer.h,v 1.7 2017/12/09 04:29:00 sarrazip Exp $
+/*  $Id: BurgerSpaceServer.h,v 1.9 2022/11/22 01:35:20 sarrazip Exp $
     BurgerSpaceServer.h - Main engine
 
     burgerspace - A hamburger-smashing video game.
-    Copyright (C) 2001-2013 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2001-2022 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -72,7 +72,9 @@ class BurgerSpaceServer : public BurgerSpaceServerInterface
 {
 public:
 
-    BurgerSpaceServer(int initLevelNumber, bool _oldMotionMode);
+    // _hideLandedEnemies: false for behavior of versions <= 1.9.4.
+    //
+    BurgerSpaceServer(int initLevelNumber, bool _oldMotionMode, bool _hideLandedEnemies);
 
     void finishInit();  // must be called after constructor -- calls virtual functions
 
@@ -307,6 +309,9 @@ protected:
     IngredientSprite::List ingredientSprites;  // owns the contained objects
     IngredientGroup::List  ingredientGroups;
                                     // contained objects must come from 'new'
+    bool hideLandedEnemies;  // after enemies carried by a slice have landed,
+                             // they are hidden (true) or shown as frozen (false)
+                             // until they revive
 
 
     /*  TREATS (icecream, etc, that the player eats to get a pepper):
