@@ -1,4 +1,4 @@
-/*  $Id: EnemySprite.h,v 1.11 2010/05/26 03:13:01 sarrazip Exp $
+/*  $Id: EnemySprite.h,v 1.12 2017/12/09 04:29:00 sarrazip Exp $
     EnemySprite.h - Sprite that represents an enemy of the player.
 
     burgerspace - A hamburger-smashing video game.
@@ -45,7 +45,7 @@ public:
                 flatzebra::Couple pos,
                 flatzebra::Couple speed,
                 flatzebra::Couple collBoxPos,
-                flatzebra::Couple collBosSize) throw(int);
+                flatzebra::Couple collBosSize);
     /*  Calls Sprite constructor.
     */
 
