@@ -1,8 +1,8 @@
-/*  $Id: LocalServer.h,v 1.2 2010/05/26 03:13:01 sarrazip Exp $
+/*  $Id: LocalServer.h,v 1.4 2022/11/22 01:35:20 sarrazip Exp $
     LocalServer.h - Direct function call server
 
     burgerspace - A hamburger-smashing video game.
-    Copyright (C) 2010 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2010-2022 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -30,8 +30,8 @@
 class LocalServer : public BurgerSpaceServer
 {
 public:
-    LocalServer(BurgerSpaceClient &_client, int initLevelNo, bool oldMotionMode)
-    :   BurgerSpaceServer(initLevelNo, oldMotionMode),
+    LocalServer(BurgerSpaceClient &_client, int initLevelNo, bool oldMotionMode, bool hideLandedEnemies)
+    :   BurgerSpaceServer(initLevelNo, oldMotionMode, hideLandedEnemies),
         client(_client)
     {
         // NOTE: finishInit() must be called on this object, outside of a constructor
