@@ -1,8 +1,8 @@
-/*  $Id: client.cpp,v 1.7 2021/06/13 02:43:46 sarrazip Exp $
+/*  $Id: client.cpp,v 1.9 2022/11/22 01:35:20 sarrazip Exp $
     client.cpp - main() function for BurgerSpace
 
     burgerspace - A hamburger-smashing video game.
-    Copyright (C) 2001-2021 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2001-2022 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -54,6 +54,7 @@ static struct option knownOptions[] =
     { "full-screen",   no_argument,       NULL, 'f' },
     { "old-motion",    no_argument,       NULL, 'o' },
     { "z-for-pepper",  no_argument,       NULL, 'z' },
+    { "hide-landed-enemies", no_argument, NULL, 'l' },
     { "server",        required_argument, NULL, 's' },
     { "port",          required_argument, NULL, 'p' },
     { "chef",          no_argument,       NULL, 'c' },
@@ -90,20 +91,21 @@ displayHelp()
     cout <<
 "\n"
 "Known options:\n"
-"--help             Display this help page and exit\n"
-"--version          Display this program's version number and exit\n"
-"--initial-level=N  Start game at level N (N >= 1) [default=1]\n"
-"--ms-per-frame=N   N milliseconds per animation frame [default=55]\n"
-"                   Min. 1, max. 1000.  50 ms means 20 frames per second\n"
-"--no-sound         Disable sound effects [default is to enable them]\n"
-"--full-screen      Attempt to use full screen mode [default is window mode]\n"
-"--old-motion       Use the old player motion system [default is new system]\n"
-"--z-for-pepper     Use Z key to shoot pepper [default is Ctrl key]\n"
-"--server=HOSTNAME  Run as a network client and use specified server\n"
-"--port=PORT        Specify UDP port of server (only relevant with --server)\n"
-"--chef             In a network game, play the role of the chef\n"
-"--enemy            In a network game, play the role of one of the enemies\n"
-"--no-active-event  Do not pause when the window becomes inactive.\n"
+"--help                 Display this help page and exit\n"
+"--version              Display this program's version number and exit\n"
+"--initial-level=N      Start game at level N (N >= 1) [default=1]\n"
+"--ms-per-frame=N       N milliseconds per animation frame [default=55]\n"
+"                       Min. 1, max. 1000.  50 ms means 20 frames per second\n"
+"--no-sound             Disable sound effects [default is to enable them]\n"
+"--full-screen          Attempt to use full screen mode [default is window mode]\n"
+"--old-motion           Use the old player motion system [default is new system]\n"
+"--z-for-pepper         Use Z key to shoot pepper [default is Ctrl key]\n"
+"--hide-landed-enemies  After an enemy lands in a plate, hide it until it revives\n"
+"--server=HOSTNAME      Run as a network client and use specified server\n"
+"--port=PORT            Specify UDP port of server (only relevant with --server)\n"
+"--chef                 In a network game, play the role of the chef\n"
+"--enemy                In a network game, play the role of one of the enemies\n"
+"--no-active-event      Do not pause when the window becomes inactive.\n"
 "\n"
     ;
 }
@@ -155,6 +157,7 @@ main(int argc, char *argv[])
     bool useSound = true;
     bool fullScreen = false;
     bool useOldMotionMode = false;
+    bool hideLandedEnemies = false;
     SDLKey pepperKey = SDLK_LCTRL;
     string serverHostname;  // UDP server hostname if not empty; local server otherwise
     unsigned short port = DEFAULT_UDP_SERVER_PORT;
@@ -218,6 +221,10 @@ main(int argc, char *argv[])
                 useOldMotionMode = true;
                 break;
 
+            case 'l':
+                hideLandedEnemies = true;  // behavior of versions <= 1.9.4
+                break;
+
             case 'z':
                 pepperKey = SDLK_z;
                 break;
@@ -325,7 +332,7 @@ main(int argc, char *argv[])
         if (standAlone)
         {
             // Create a "local server":
-            LocalServer *ls = new LocalServer(theBurgerSpaceClient, initLevelNo, useOldMotionMode);
+            LocalServer *ls = new LocalServer(theBurgerSpaceClient, initLevelNo, useOldMotionMode, hideLandedEnemies);
             ls->finishInit();
             serverInterface = ls;
         }
