@@ -1,8 +1,8 @@
-/*  $Id: server.cpp,v 1.5 2018/06/24 20:53:05 sarrazip Exp $
+/*  $Id: server.cpp,v 1.7 2022/11/22 01:35:20 sarrazip Exp $
     server.cpp - main() function for BurgerSpace server
 
     burgerspace - A hamburger-smashing video game.
-    Copyright (C) 2008 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2008-2022 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -305,7 +305,7 @@ class BurgerSpaceCommandLineServer : public BurgerSpaceServer
 public:
 
     BurgerSpaceCommandLineServer(int _initLevelNumber, int _sock, Uint32 _minMSBetweenWrites)
-      : BurgerSpaceServer(_initLevelNumber, false),
+      : BurgerSpaceServer(_initLevelNumber, false, false),
         sock(_sock),
         minMSBetweenWrites(_minMSBetweenWrites),
         pendingLevelUpdatePacket(),
